==> foundation-ui-components-1.8.1.tgz: package/src/common/accordion/NsCollapse.tsx <==
import { styled } from '@nuskin/foundation-theme';
import {
    AccordionVariant,
    AccordionVariantType,
    NsCollapseProps,
    AccordionItem,
    NsAccordion,
    AccordionContentTypeObject,
} from '../';
import { getAccordionColor } from './colorMap';
import { ReactElement, isValidElement, useMemo } from 'react';

const getLevelOffset = (level: number) => {
    return level > 1 ? (level - 1) * 16 : 0;
};

const options = {
    shouldForwardProp: (key: string) => !['variant', 'level'].includes(key),
};

export const StyledCollapse = styled(
    'section',
    options
)<{ variant: AccordionVariantType; level: number; invert: boolean; isChild: boolean }>(
    ({ theme, variant, level, invert, isChild }) => {
        const { contentBg, contentText } = getAccordionColor({
            theme,
            invert,
            variant,
            keys: ['contentBg', 'contentText'],
        });

        let borderBottom = 'none';
        if (variant === AccordionVariant.Compact) {
            borderBottom = isChild ? 'none' : '1px solid rgb(0,0,0,0.125)';
        }
        return {
            backgroundColor: contentBg,
            color: contentText,
            opacity: 0,
            padding: '0 16px',
            height: 0,
            overflow: 'hidden',
            transition: '0.3s',
            '&.expanded': {
                padding: `9px 0 9px ${getLevelOffset(level)}px`,
                height: 'auto',
                opacity: 1,
                borderBottom,
            },
            '.nsa-content-padded': {
                padding: '0 16px 16px',
            },
        };
    }
);

/**
 * NsCollapse component adds css animation while showing children items if prop `isOpen` is true,
 * and while removing children if prop `isOpen` is false
 */
const NsCollapse = ({
    isOpen,
    content,
    additionalProps,
    variant,
    level,
    invert,
    isChild,
    type,
    cslp,
    allowMultipleExpanded,
}: NsCollapseProps) => {
    const body = useMemo(() => {
        if (isValidElement(content)) {
            return content as ReactElement;
        }
        if (type === AccordionContentTypeObject.html) {
            return (
                <div
                    className="nsa-content-padded"
                    dangerouslySetInnerHTML={{ __html: content as string }}
                    {...(cslp?.content ?? {})}
                />
            );
        } else if (type === AccordionContentTypeObject.text) {
            return (
                <div className="p-4" {...(cslp?.content ?? {})}>
                    {content as string}
                </div>
            );
        } else if (type === AccordionContentTypeObject.accordion) {
            return (
                <NsAccordion
                    isChild={true}
                    invert={invert}
                    level={level}
                    variant={AccordionVariant.Gray}
                    items={content as AccordionItem[]}
                    allowMultipleExpanded={allowMultipleExpanded ?? false}
                />
            );
        }
        return null;
    }, [allowMultipleExpanded, content, cslp?.content, invert, level, type]);
    return (
        <StyledCollapse
            isChild={isChild}
            level={level}
            className={`ns-collapse ${isOpen ? 'expanded' : ''} ${additionalProps?.className ?? ''}`}
            variant={variant}
            invert={invert}
        >
            {body}
        </StyledCollapse>
    );
};
export default NsCollapse;

==> foundation-ui-components-1.11.0.tgz: package/src/common/accordion/NsCollapse.tsx <==
import { styled } from '@nuskin/foundation-theme';
import { isValidElement, ReactElement, useMemo } from 'react';

import {
    AccordionContentTypeObject,
    AccordionItem,
    AccordionVariant,
    AccordionVariantType,
    NsAccordion,
    NsCollapseProps,
} from '../';
import { getAccordionColor } from './colorMap';

const getLevelOffset = (level: number) => {
    return level > 1 ? (level - 1) * 16 : 0;
};
type CollapsePropsType = { variant: AccordionVariantType; level: number; invert: boolean; isChild: boolean };

export const StyledCollapse = styled('section')<CollapsePropsType>(({ theme, variant, level, invert, isChild }) => {
    const { contentBg, contentText } = getAccordionColor({
        theme,
        invert,
        variant,
        keys: ['contentBg', 'contentText'],
    });

    let borderBottom = 'none';
    if (variant === AccordionVariant.Compact) {
        borderBottom = isChild ? 'none' : '1px solid rgb(0,0,0,0.125)';
    }
    return {
        backgroundColor: contentBg,
        color: contentText,
        opacity: 0,
        padding: '0 16px',
        height: 0,
        overflow: 'hidden',
        transition: '0.3s',
        '&.expanded': {
            padding: `9px 0 9px ${getLevelOffset(level)}px`,
            height: 'auto',
            opacity: 1,
            borderBottom,
        },
        '.nsa-content-padded': {
            padding: '0 16px 16px',
        },
    };
});

/**
 * NsCollapse component adds css animation while showing children items if prop `isOpen` is true,
 * and while removing children if prop `isOpen` is false
 */
const NsCollapse = ({
    isOpen,
    content,
    additionalProps,
    variant,
    level,
    invert,
    isChild,
    type,
    cslp,
    allowMultipleExpanded,
}: NsCollapseProps) => {
    const body = useMemo(() => {
        if (isValidElement(content)) {
            return content as ReactElement;
        }
        if (type === AccordionContentTypeObject.html) {
            return (
                <div
                    className="nsa-content-padded"
                    dangerouslySetInnerHTML={{ __html: content as string }}
                    {...(cslp?.content ?? {})}
                />
            );
        } else if (type === AccordionContentTypeObject.text) {
            return (
                <div className="p-4" {...(cslp?.content ?? {})}>
                    {content as string}
                </div>
            );
        } else if (type === AccordionContentTypeObject.accordion) {
            return (
                <NsAccordion
                    isChild={true}
                    invert={invert}
                    level={level}
                    variant={AccordionVariant.Gray}
                    items={content as AccordionItem[]}
                    allowMultipleExpanded={allowMultipleExpanded ?? false}
                />
            );
        }
        return null;
    }, [allowMultipleExpanded, content, cslp?.content, invert, level, type]);
    return (
        <StyledCollapse
            isChild={isChild}
            level={level}
            className={`ns-collapse ${isOpen ? 'expanded' : ''} ${additionalProps?.className ?? ''}`}
            variant={variant}
            invert={invert}
        >
            {body}
        </StyledCollapse>
    );
};
export default NsCollapse;
